@@ -1,30 +1,39 @@
 """Losses for Importance Sampled Fitted V Iteration."""
+from typing import Callable
+from typing import Tuple
+
 import torch
 from ray.rllib import SampleBatch
 from ray.rllib.utils import override
+from torch import Tensor
 
 import raylab.utils.dictionaries as dutil
+from raylab.utils.annotations import StateValue
+from raylab.utils.annotations import StochasticPolicy
+
+from .abstract import Loss
 
 
-class ISFittedVIteration:
+class ISFittedVIteration(Loss):
     """Loss function for Importance Sampled Fitted V Iteration.
 
     Args:
-        critic (callable): state-value function
-        target_critic (callable): state-value function for the next state
-        gamma (float): discount factor
+        critic: state-value function
+        target_critic: state-value function for the next state
+        gamma: discount factor
     """
 
     IS_RATIOS = "is_ratios"
+    batch_keys: Tuple[str, str] = (SampleBatch.CUR_OBS, "is_ratios")
 
-    def __init__(self, critic, target_critic, **config):
+    def __init__(self, critic: StateValue, target_critic: StateValue, gamma: float):
         self.critic = critic
         self.target_critic = target_critic
-        self.config = config
+        self.gamma = gamma
 
     def __call__(self, batch):
         """Compute loss for importance sampled fitted V iteration."""
-        obs, is_ratios = dutil.get_keys(batch, SampleBatch.CUR_OBS, self.IS_RATIOS)
+        obs, is_ratios = dutil.get_keys(batch, *self.batch_keys)
 
         values = self.critic(obs).squeeze(-1)
         with torch.no_grad():
@@ -42,7 +51,7 @@ class ISFittedVIteration:
         return torch.where(
             dones,
             rewards,
-            rewards + self.config["gamma"] * self.target_critic(next_obs).squeeze(-1),
+            rewards + self.gamma * self.target_critic(next_obs).squeeze(-1),
         )
 
 
@@ -50,18 +59,26 @@ class ISSoftVIteration(ISFittedVIteration):
     """Loss function for Importance Sampled Soft V Iteration.
 
     Args:
-        critic (callable): state-value function
-        target_critic (callable): state-value function for the next state
-        actor (callable): stochastic policy
-        alpha (callable): entropy coefficient schedule
-        gamma (float): discount factor
+        critic: state-value function
+        target_critic: state-value function for the next state
+        actor: stochastic policy
+        alpha: entropy coefficient schedule
+        gamma: discount factor
     """
 
     # pylint:disable=too-few-public-methods
     ENTROPY = "entropy"
 
-    def __init__(self, critic, target_critic, actor, alpha, **config):
-        super().__init__(critic, target_critic, **config)
+    def __init__(
+        self,
+        critic: StateValue,
+        target_critic: StateValue,
+        actor: StochasticPolicy,
+        alpha: Callable[[], Tensor],
+        gamma: float,
+    ):
+        # pylint:disable=too-many-arguments
+        super().__init__(critic, target_critic, gamma=gamma)
         self.actor = actor
         self.alpha = alpha
 
@@ -78,10 +95,9 @@ class ISSoftVIteration(ISFittedVIteration):
         next_obs, rewards, dones = dutil.get_keys(
             batch, SampleBatch.NEXT_OBS, SampleBatch.REWARDS, SampleBatch.DONES,
         )
-        gamma = self.config["gamma"]
         augmented_rewards = rewards + self.alpha() * entropy
         return torch.where(
             dones,
             augmented_rewards,
-            augmented_rewards + gamma * self.target_critic(next_obs).squeeze(-1),
+            augmented_rewards + self.gamma * self.target_critic(next_obs).squeeze(-1),
         )
